// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-

/* Copyright (c) Chris Vine, 2012 to 2023
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import GObject from "gi://GObject";
import Gio from "gi://Gio";
import Gtk from "gi://Gtk";

import {ExtensionPreferences, gettext} from "resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js";

class FavoritesPrefsWidget extends Gtk.Grid {
    static {
        GObject.registerClass(this);
    }

    constructor(settings) {
        super();

        this.margin_top = 40;
        this.margin_start = 40;
	this.row_spacing = 20;
	this.column_spacing = 10;
	this.attach(new Gtk.Label({label: gettext("Panel Icon"),
		 		   justify: Gtk.Justification.RIGHT,
				   xalign: 1,
				   yalign: 0.5,
                                   halign: Gtk.Align.START}),
                    0, 0, 1, 1);
	let icon_check = new Gtk.CheckButton;
	this.attach(icon_check, 1, 0, 1, 1);

	this.attach(new Gtk.Label({label: gettext("Panel Position"),
				   justify: Gtk.Justification.RIGHT,
				   xalign: 1,
				   yalign: 0.5,
                                   halign: Gtk.Align.START}),
                    0, 1, 1, 1);
	let spin = new Gtk.SpinButton;
	spin.set_range(1, 5);
	spin.set_increments(1, 1);
	this.attach(spin, 1, 1, 1, 1);

	this._settings = settings;
	this._settings.bind("icon", icon_check, "active", Gio.SettingsBindFlags.DEFAULT);
	this._settings.bind("position", spin, "value", Gio.SettingsBindFlags.DEFAULT);
    }
}

export default class FavoritesPrefs extends ExtensionPreferences {
    getPreferencesWidget() {
        return new FavoritesPrefsWidget(this.getSettings());
    }
}
